from paste.script import templates
from paste.script.templates import var

class JsonRpcTemplate(templates.BasicPackage):

    summary = 'A jsonrpc2 project.'
    _template_dir = 'paster_jsonrpc2_template'
    vars = [
    ]
